==> qtrename-1.1.0.tar.gz: qtrename-1.1.0/qtrename/__init__.py <==
############################################################################
##############################################################################
##   Feature-rich app to rename files for GNU/Linux and Windows             ##
##   Copyright (C) 2020  Mohamed Jouini                                     ##
##                                                                          ##
##   This program is free software: you can redistribute it and/or modify   ##
##   it under the terms of the GNU General Public License as published by   ##
##   the Free Software Foundation, either version 3 of the License, or      ##
##   (at your option) any later version.                                    ##
##                                                                          ##
##   This program is distributed in the hope that it will be useful,        ##
##   but WITHOUT ANY WARRANTY; without even the implied warranty of         ##
##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          ##
##   GNU General Public License for more details.                           ##
##                                                                          ##
##   You should have received a copy of the GNU General Public License      ##
##   along with this program.  If not, see <https://www.gnu.org/licenses/>. ##
##############################################################################
############################################################################

__all__ = ["About", "Errors", "mainwindow", "preview", "spaces", "worker", "add_remove", "casing", "fetcher", "move", "qtrenamer_rc", "TableView", "Animation", "common", "main", "counters", "replace", "Theme"]

from . import About
from . import Errors
from . import mainwindow
from . import preview
from . import spaces
from . import worker
from . import add_remove
from . import casing
from . import fetcher
from . import move
from . import qtrenamer_rc
from . import TableView
from . import Animation
from . import common
from . import main
from . import counters
from . import replace
from . import Theme

==> qtrename-1.1.1.tar.gz: qtrename-1.1.1/qtrename/__init__.py <==
############################################################################
##############################################################################
##   Feature-rich app to rename files for GNU/Linux and Windows             ##
##   Copyright (C) 2020  Mohamed Jouini                                     ##
##                                                                          ##
##   This program is free software: you can redistribute it and/or modify   ##
##   it under the terms of the GNU General Public License as published by   ##
##   the Free Software Foundation, either version 3 of the License, or      ##
##   (at your option) any later version.                                    ##
##                                                                          ##
##   This program is distributed in the hope that it will be useful,        ##
##   but WITHOUT ANY WARRANTY; without even the implied warranty of         ##
##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          ##
##   GNU General Public License for more details.                           ##
##                                                                          ##
##   You should have received a copy of the GNU General Public License      ##
##   along with this program.  If not, see <https://www.gnu.org/licenses/>. ##
##############################################################################
############################################################################

__all__ = ["About", "Errors", "mainwindow", "preview", "spaces", "worker", "add_remove", "casing", "move", "qtrenamer_rc", "TableView", "Animation", "common", "main", "counters", "replace", "Theme"]

from . import About
from . import Errors
from . import mainwindow
from . import preview
from . import spaces
from . import worker
from . import add_remove
from . import casing
from . import move
from . import qtrenamer_rc
from . import TableView
from . import Animation
from . import common
from . import main
from . import counters
from . import replace
from . import Theme
